@@ -87,6 +87,12 @@ class Policy(object):
         self.manage = manage
         self.accept = accept
 
+    def __eq__(self, other):
+        return self.__dict__ == other.__dict__
+
+    def __ne__(self, other):
+        return not self == other
+
     def allows(self, usersign, constraint):
         """
         Is the user encapsulated by the ``usersign`` dict allowed to
