@@ -6,8 +6,6 @@ supports search.
 
 import logging
 
-import urllib
-
 from httpexceptor import HTTP400
 
 from tiddlyweb.control import readable_tiddlers_by_bag
@@ -26,7 +24,6 @@ def get_search_query(environ):
     """
     try:
         search_query = environ['tiddlyweb.query']['q'][0]
-        search_query = urllib.unquote(search_query)
     except (KeyError, IndexError):
         raise HTTP400('query string required')
     return search_query
@@ -78,7 +75,7 @@ def get(environ, start_response):
 
     except StoreMethodNotImplemented:
         raise HTTP400('Search system not implemented')
-    except StoreError, exc:
+    except StoreError as exc:
         raise HTTP400('Error while processing search: %s' % exc)
 
     return send_tiddlers(environ, start_response, tiddlers=candidate_tiddlers)
