@@ -15,7 +15,9 @@ from tiddlyweb.model.collections import Tiddlers
 from tiddlyweb.serializer import Serializer, NoSerializationError
 from tiddlyweb.util import sha
 from tiddlyweb.web.util import (get_serialize_type, http_date_from_timestamp,
-        check_last_modified, check_incoming_etag)
+        check_last_modified, check_incoming_etag, encode_name)
+
+from tiddlyweb.fixups import basestring
 
 
 LOGGER = logging.getLogger(__name__)
@@ -50,7 +52,7 @@ def send_tiddlers(environ, start_response, tiddlers=None):
 
     if download:
         response.append(('Content-Disposition',
-            'attachment; filename="%s"' % download.encode('utf-8')))
+            'attachment; filename="%s"' % encode_name(download)))
 
     if last_modified:
         response.append(last_modified)
@@ -61,10 +63,10 @@ def send_tiddlers(environ, start_response, tiddlers=None):
     try:
         serializer = Serializer(serialize_type, environ)
         output = serializer.list_tiddlers(candidate_tiddlers)
-    except NoSerializationError, exc:
+    except NoSerializationError as exc:
         raise HTTP415('Content type not supported: %s:%s, %s' %
                 (serialize_type, mime_type, exc))
-    except FilterError, exc:  # serializations may filter tildders
+    except FilterError as exc:  # serializations may filter tildders
         raise HTTP400('malformed filter or tiddler during filtering: %s' % exc)
 
     start_response("200 OK", response)
@@ -92,7 +94,7 @@ def _filter_tiddlers(filters, store, tiddlers):
     try:
         for tiddler in recursive_filter(filters, tiddlers):
             candidate_tiddlers.add(tiddler)
-    except FilterError, exc:
+    except FilterError as exc:
         raise HTTP400('malformed filter: %s' % exc)
     return candidate_tiddlers
 
@@ -120,7 +122,7 @@ def _validate_tiddler_list(environ, tiddlers):
     except TypeError:
         mime_type = ''
     etag_string = '"%s:%s"' % (tiddlers.hexdigest(),
-            sha('%s:%s' % (username.encode('utf-8'), mime_type)).hexdigest())
+            sha('%s:%s' % (username, mime_type)).hexdigest())
     etag = ('Etag', etag_string)
 
     incoming_etag = check_incoming_etag(environ, etag_string,
